summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorVanessa Ezekowitz <vanessaezekowitz@gmail.com>2013-01-30 21:51:18 -0500
committerVanessa Ezekowitz <vanessaezekowitz@gmail.com>2013-01-30 21:51:18 -0500
commitbf4d4929f7993debef271feed1aa8b793336ca9b (patch)
treed2b394f7634ff76e095be3b4552ab89356cb8b13
parentb3fd7390398c2f79e071003e45cb39719dbc212c (diff)
made leaves drop saplings at a lower rate (was 1/20, now 1/100)
-rw-r--r--biome_defs.lua22
-rw-r--r--node_defs.lua14
2 files changed, 5 insertions, 31 deletions
diff --git a/biome_defs.lua b/biome_defs.lua
index 5b1c1a6..155101b 100644
--- a/biome_defs.lua
+++ b/biome_defs.lua
@@ -1,25 +1,3 @@
---[[
-
--- Example biome definition:
-
-moretrees.mytree_biome = {
- surface = "default:dirt_with_grass", -- must grow on these nodes only
- avoid_nodes = {"default:tree"}, -- avoid spawning near these
- avoid_radius = 5, -- Keep this much room around the above avoid items
- rarity = 50, -- tree rarity: math.random(1,100) > this (higher = more rare)
- seed_diff = 12345, -- perlin seed-diff for "generally able to grow plants here" control
- neighbors = "default:dirt_with_grass", -- this node must be adjacent to the node being spawned on
- ncount = 8, -- and there must be this many of them
- depth = 1, -- spawning surface must be no deeper than this
- min_elevation = -5, -- minimum elevation to spawn on
- max_elevation = 10, -- maximum elevation
- near_nodes = {"default:water_source"}, -- trees will only spawn near these nodes
- near_nodes_size = 10, -- within this radius of at least one of them
- near_nodes_count = 20, -- there must ne this many of those nodes in the area
- temp_min = 0.5, -- minimum allowable temperature (highest temperature map perlin value)
- temp_max = 0.1, -- maximum allowable temperature (lowest perlin value)
-}
-]]--
moretrees.beech_biome = {
surface = "default:dirt_with_grass",
diff --git a/node_defs.lua b/node_defs.lua
index cc7699a..11761d1 100644
--- a/node_defs.lua
+++ b/node_defs.lua
@@ -105,8 +105,8 @@ for i in ipairs(trees) do
})
end
- -- player will get sapling with 1/20 chance
- -- player will get leaves only if he get no saplings,
+ -- player will get a sapling with 1/100 chance
+ -- player will get leaves only if he/she gets no saplings,
-- this is because max_items is 1
if treename ~= "jungletree" then
@@ -118,14 +118,10 @@ for i in ipairs(trees) do
groups = {tree=1, snappy=3, flammable=2 },
sounds = default.node_sound_leaves_defaults(),
- -- player will get sapling with 1/20 chance
- -- player will get leaves only if he/she gets no
- -- saplings, because max_items is 1.
-
drop = {
max_items = 1,
items = {
- {items = {"moretrees:"..treename.."_sapling"}, rarity = 20 },
+ {items = {"moretrees:"..treename.."_sapling"}, rarity = 100 },
{items = {"moretrees:"..treename.."_leaves"} }
}
},
@@ -151,7 +147,7 @@ for color = 1, 3 do
drop = {
max_items = 1,
items = {
- {items = {'moretrees:jungletree_sapling'}, rarity = 20 },
+ {items = {'moretrees:jungletree_sapling'}, rarity = 100 },
{items = {"moretrees:jungletree_leaves_"..jungleleaves[color]} }
}
},
@@ -171,7 +167,7 @@ minetest.register_node("moretrees:fir_leaves_bright", {
drop = {
max_items = 1,
items = {
- {items = {'moretrees:fir_sapling'}, rarity = 20 },
+ {items = {'moretrees:fir_sapling'}, rarity = 100 },
{items = {'moretrees:fir_leaves'} }
}
},